# Has Notifications

[![Build Status](https://travis-ci.org/vladzzag/has_notifications.svg)](https://travis-ci.org/vladzzag/has_notifications)

Simple notification system for Ruby on Rails.

## Installation

Generate tables that are required by ```has_notification```:
```shell
$ gem install has_notifications
$ rails generate has_notifications:migration
$ rake db:migrate
```

## Usage

Model which will be notificated:
```ruby
class User < ActiveRecord::Base
    has_notifications
end
```

Notification model:
```ruby
class Notification < ActiveRecord::Base
    acts_as_notification
end
```

Notify:
```ruby
vlad = User.create!(name: "Vlad")
notification = Notification.create!(message: "Hello, World!")

vlad.notify(notification)
```

Get all notifications:
```ruby
vlad = User.first
vlad.all_notifications
=> [...]
```

Get all unwatched notifications:
```ruby
vlad = User.first
vlad.unwatched_notifications
=> [...]
```

Get all watched notifications:
```ruby
vlad = User.first
vlad.watched_notifications
=> [...]
```

Mark notification as watched:
```ruby
vlad = User.first
notification = vlad.unwatched_notifications[0]
=> <...>
notification.mark_as_watched
```

Callbacks(blocks and lambdas aren't supported):
```ruby
class User < ActiveRecord::Base
    has_notifications
    on_notification :callback

    def callback notification
    	# fancy code...
    end
end
```

## Contributing

0. Take a look at TODO.txt
1. Fork it ( https://github.com/vladzzag/has_notifications/fork )
2. Create your feature branch (`git checkout -b my-new-feature`)
3. Commit your changes (`git commit -am 'Add some feature'`)
4. Push to the branch (`git push origin my-new-feature`)
5. Create a new Pull Request
